# Lintly Changelog

## 0.1.0 (Not released)

* Initial release
* Support for Python 2.7 and 3.4+
* Support for GitHub repos
* Support for Flake8, Pylint, ESLint, and Stylelint
* Support for Travis CI, Circle CI, AppVeyor, Shippable, Semaphore, and CodeBuild
